@@ -39,8 +39,8 @@
 
 .check_clear_cache <- function(self) {
     .latest_update_timestamp <- .get_latest_update_timestamp(self)
-    if (.latest_update_timestamp > self$latest_update_timestamp) {
-        cat(crayon::yellow("  INFO: New data found. Clearing session cache and refreshing `AmericanSoccerAnalysis` class.\n"))
+    if (is.null(self$latest_update_timestamp) || .latest_update_timestamp > self$latest_update_timestamp) {
+        cli::cat_line("  INFO: New data found. Clearing session cache and refreshing `AmericanSoccerAnalysis` class.", col = "yellow")
         httpcache::clearCache()
         .initialize_entities(self)
         self$latest_update_timestamp <- .latest_update_timestamp
@@ -58,7 +58,7 @@
     }
 
     latest_update_timestamp <- data.table::rbindlist(games, fill = TRUE) %>%
-        dplyr::pull(.data$last_updated_utc) %>%
+        dplyr::pull("last_updated_utc") %>%
         max(na.rm = TRUE) %>%
         as.POSIXct(format="%Y-%m-%d %H:%M:%S", tz="UTC")
 
