@@ -18,13 +18,13 @@ test_that("Querying player-level goals added (g+) values works properly", {
     LEAGUES <- "mls"
 
     .exp <- asa_client$players %>%
-        tidyr::unnest(.data$competitions) %>%
-        dplyr::filter(.data$competitions %in% LEAGUES) %>%
-        dplyr::distinct(.data$player_id) %>%
-        dplyr::pull(.data$player_id)
+        tidyr::unnest(competitions) %>%
+        dplyr::filter(competitions %in% LEAGUES) %>%
+        dplyr::distinct(player_id) %>%
+        dplyr::pull(player_id)
 
     .obj <- asa_client$get_player_goals_added(leagues = LEAGUES) %>%
-        dplyr::mutate(obj = .data$player_id %in% .exp) %>%
+        dplyr::mutate(obj = player_id %in% .exp) %>%
         dplyr::pull(obj) %>%
         mean(na.rm = TRUE)
 
@@ -34,13 +34,13 @@ test_that("Querying player-level goals added (g+) values works properly", {
     LEAGUES <- c("mls", "uslc")
 
     .exp <- asa_client$players %>%
-        tidyr::unnest(.data$competitions) %>%
-        dplyr::filter(.data$competitions %in% LEAGUES) %>%
-        dplyr::distinct(.data$player_id) %>%
-        dplyr::pull(.data$player_id)
+        tidyr::unnest(competitions) %>%
+        dplyr::filter(competitions %in% LEAGUES) %>%
+        dplyr::distinct(player_id) %>%
+        dplyr::pull(player_id)
 
     .obj <- asa_client$get_player_goals_added(leagues = LEAGUES) %>%
-        dplyr::mutate(obj = .data$player_id %in% .exp) %>%
+        dplyr::mutate(obj = player_id %in% .exp) %>%
         dplyr::pull(obj) %>%
         mean(na.rm = TRUE)
 
@@ -49,7 +49,7 @@ test_that("Querying player-level goals added (g+) values works properly", {
     # Minimum minutes ----------------------------------------------------
     .exp <- 1000
     .obj <- asa_client$get_player_goals_added(minimum_minutes = .exp) %>%
-        dplyr::pull(.data$minutes_played) %>%
+        dplyr::pull(minutes_played) %>%
         min()
 
     expect_gte(.obj, .exp)
@@ -61,11 +61,11 @@ test_that("Querying player-level goals added (g+) values works properly", {
     IDS <- "vzqo8xZQap"
 
     .obj <- asa_client$get_player_goals_added(player_ids = IDS) %>%
-        dplyr::distinct(.data$player_id) %>%
+        dplyr::distinct(player_id) %>%
         nrow()
 
     .exp <- asa_client$players %>%
-        dplyr::filter(.data$player_id %in% IDS) %>%
+        dplyr::filter(player_id %in% IDS) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -74,11 +74,11 @@ test_that("Querying player-level goals added (g+) values works properly", {
     IDS <- c("vzqo8xZQap", "9vQ22BR7QK")
 
     .obj <- asa_client$get_player_goals_added(player_ids = IDS) %>%
-        dplyr::distinct(.data$player_id) %>%
+        dplyr::distinct(player_id) %>%
         nrow()
 
     .exp <- asa_client$players %>%
-        dplyr::filter(.data$player_id %in% IDS) %>%
+        dplyr::filter(player_id %in% IDS) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -87,11 +87,11 @@ test_that("Querying player-level goals added (g+) values works properly", {
     NAMES <- "Dax McCarty"
 
     .obj <- asa_client$get_player_goals_added(player_names = NAMES) %>%
-        dplyr::distinct(.data$player_id) %>%
+        dplyr::distinct(player_id) %>%
         nrow()
 
     .exp <- asa_client$players %>%
-        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), .data$player_name)) %>%
+        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), player_name)) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -100,11 +100,11 @@ test_that("Querying player-level goals added (g+) values works properly", {
     NAMES <- c("Dax McCarty", "Tiffany McCarty")
 
     .obj <- asa_client$get_player_goals_added(player_names = NAMES) %>%
-        dplyr::distinct(.data$player_id) %>%
+        dplyr::distinct(player_id) %>%
         nrow()
 
     .exp <- asa_client$players %>%
-        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), .data$player_name)) %>%
+        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), player_name)) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -116,12 +116,12 @@ test_that("Querying player-level goals added (g+) values works properly", {
     IDS <- "NWMWlBK5lz"
 
     .obj <- asa_client$get_player_goals_added(team_ids = IDS) %>%
-        tidyr::unnest(.data$team_id) %>%
-        dplyr::distinct(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
+        dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(.data$team_id %in% IDS) %>%
+        dplyr::filter(team_id %in% IDS) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -130,12 +130,12 @@ test_that("Querying player-level goals added (g+) values works properly", {
     IDS <- c("a2lqRX2Mr0", "9Yqdwg85vJ")
 
     .obj <- asa_client$get_player_goals_added(team_ids = IDS) %>%
-        tidyr::unnest(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
         dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(.data$team_id %in% IDS) %>%
+        dplyr::filter(team_id %in% IDS) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -144,12 +144,12 @@ test_that("Querying player-level goals added (g+) values works properly", {
     NAMES <- "Red Bulls"
 
     .obj <- asa_client$get_player_goals_added(team_names = NAMES) %>%
-        tidyr::unnest(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
         dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), .data$team_name)) %>%
+        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), team_name)) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -158,12 +158,12 @@ test_that("Querying player-level goals added (g+) values works properly", {
     NAMES <- c("Chicago", "Seattle")
 
     .obj <- asa_client$get_player_goals_added(team_names = NAMES) %>%
-        tidyr::unnest(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
         dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), .data$team_name)) %>%
+        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), team_name)) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -189,38 +189,38 @@ test_that("Querying player-level goals added (g+) values works properly", {
     # Single action type -------------------------------------------------
     .exp <- "Passing"
     .obj <- asa_client$get_player_goals_added(action_type = .exp) %>%
-        tidyr::unnest(.data$data) %>%
-        dplyr::distinct(.data$action_type) %>%
-        dplyr::arrange(.data$action_type) %>%
-        dplyr::pull(.data$action_type)
+        tidyr::unnest(data) %>%
+        dplyr::distinct(action_type) %>%
+        dplyr::arrange(action_type) %>%
+        dplyr::pull(action_type)
 
     expect_equal(.obj, .exp)
 
     # Multiple action types ----------------------------------------------
     .exp <- c("Passing", "Shooting")
     .obj <- asa_client$get_player_goals_added(action_type = .exp) %>%
-        tidyr::unnest(.data$data) %>%
-        dplyr::distinct(.data$action_type) %>%
-        dplyr::arrange(.data$action_type) %>%
-        dplyr::pull(.data$action_type)
+        tidyr::unnest(data) %>%
+        dplyr::distinct(action_type) %>%
+        dplyr::arrange(action_type) %>%
+        dplyr::pull(action_type)
 
     expect_equal(.obj, .exp)
 
     # Single position ----------------------------------------------------
     .exp <- "AM"
     .obj <- asa_client$get_player_goals_added(general_position = .exp) %>%
-        dplyr::distinct(.data$general_position) %>%
-        dplyr::arrange(.data$general_position) %>%
-        dplyr::pull(.data$general_position)
+        dplyr::distinct(general_position) %>%
+        dplyr::arrange(general_position) %>%
+        dplyr::pull(general_position)
 
     expect_equal(.obj, .exp)
 
     # Multiple positions -------------------------------------------------
     .exp <- c("AM", "DM")
     .obj <- asa_client$get_player_goals_added(general_position = .exp) %>%
-        dplyr::distinct(.data$general_position) %>%
-        dplyr::arrange(.data$general_position) %>%
-        dplyr::pull(.data$general_position)
+        dplyr::distinct(general_position) %>%
+        dplyr::arrange(general_position) %>%
+        dplyr::pull(general_position)
 
     expect_equal(.obj, .exp)
 
@@ -254,13 +254,13 @@ test_that("Querying goalkeeper-level goals added (g+) values works properly", {
     LEAGUES <- "mls"
 
     .exp <- asa_client$players %>%
-        tidyr::unnest(.data$competitions) %>%
-        dplyr::filter(.data$competitions %in% LEAGUES) %>%
-        dplyr::distinct(.data$player_id) %>%
-        dplyr::pull(.data$player_id)
+        tidyr::unnest(competitions) %>%
+        dplyr::filter(competitions %in% LEAGUES) %>%
+        dplyr::distinct(player_id) %>%
+        dplyr::pull(player_id)
 
     .obj <- asa_client$get_goalkeeper_goals_added(leagues = LEAGUES) %>%
-        dplyr::mutate(obj = .data$player_id %in% .exp) %>%
+        dplyr::mutate(obj = player_id %in% .exp) %>%
         dplyr::pull(obj) %>%
         mean(na.rm = TRUE)
 
@@ -270,13 +270,13 @@ test_that("Querying goalkeeper-level goals added (g+) values works properly", {
     LEAGUES <- c("mls", "uslc")
 
     .exp <- asa_client$players %>%
-        tidyr::unnest(.data$competitions) %>%
-        dplyr::filter(.data$competitions %in% LEAGUES) %>%
-        dplyr::distinct(.data$player_id) %>%
-        dplyr::pull(.data$player_id)
+        tidyr::unnest(competitions) %>%
+        dplyr::filter(competitions %in% LEAGUES) %>%
+        dplyr::distinct(player_id) %>%
+        dplyr::pull(player_id)
 
     .obj <- asa_client$get_goalkeeper_goals_added(leagues = LEAGUES) %>%
-        dplyr::mutate(obj = .data$player_id %in% .exp) %>%
+        dplyr::mutate(obj = player_id %in% .exp) %>%
         dplyr::pull(obj) %>%
         mean(na.rm = TRUE)
 
@@ -285,7 +285,7 @@ test_that("Querying goalkeeper-level goals added (g+) values works properly", {
     # Minimum minutes ----------------------------------------------------
     .exp <- 1000
     .obj <- asa_client$get_goalkeeper_goals_added(minimum_minutes = .exp) %>%
-        dplyr::pull(.data$minutes_played) %>%
+        dplyr::pull(minutes_played) %>%
         min()
 
     expect_gte(.obj, .exp)
@@ -297,11 +297,11 @@ test_that("Querying goalkeeper-level goals added (g+) values works properly", {
     IDS <- "vzqoWbkqap"
 
     .obj <- asa_client$get_goalkeeper_goals_added(player_ids = IDS) %>%
-        dplyr::distinct(.data$player_id) %>%
+        dplyr::distinct(player_id) %>%
         nrow()
 
     .exp <- asa_client$players %>%
-        dplyr::filter(.data$player_id %in% IDS) %>%
+        dplyr::filter(player_id %in% IDS) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -310,11 +310,11 @@ test_that("Querying goalkeeper-level goals added (g+) values works properly", {
     IDS <- c("vzqoWbkqap", "gOMn6OlmMw")
 
     .obj <- asa_client$get_goalkeeper_goals_added(player_ids = IDS) %>%
-        dplyr::distinct(.data$player_id) %>%
+        dplyr::distinct(player_id) %>%
         nrow()
 
     .exp <- asa_client$players %>%
-        dplyr::filter(.data$player_id %in% IDS) %>%
+        dplyr::filter(player_id %in% IDS) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -323,11 +323,11 @@ test_that("Querying goalkeeper-level goals added (g+) values works properly", {
     NAMES <- "Luis Robles"
 
     .obj <- asa_client$get_goalkeeper_goals_added(player_names = NAMES) %>%
-        dplyr::distinct(.data$player_id) %>%
+        dplyr::distinct(player_id) %>%
         nrow()
 
     .exp <- asa_client$players %>%
-        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), .data$player_name)) %>%
+        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), player_name)) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -336,11 +336,11 @@ test_that("Querying goalkeeper-level goals added (g+) values works properly", {
     NAMES <- c("Luis Robles", "Ryan Meara")
 
     .obj <- asa_client$get_goalkeeper_goals_added(player_names = NAMES) %>%
-        dplyr::distinct(.data$player_id) %>%
+        dplyr::distinct(player_id) %>%
         nrow()
 
     .exp <- asa_client$players %>%
-        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), .data$player_name)) %>%
+        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), player_name)) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -352,12 +352,12 @@ test_that("Querying goalkeeper-level goals added (g+) values works properly", {
     IDS <- "NWMWlBK5lz"
 
     .obj <- asa_client$get_goalkeeper_goals_added(team_ids = IDS) %>%
-        tidyr::unnest(.data$team_id) %>%
-        dplyr::distinct(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
+        dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(.data$team_id %in% IDS) %>%
+        dplyr::filter(team_id %in% IDS) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -366,12 +366,12 @@ test_that("Querying goalkeeper-level goals added (g+) values works properly", {
     IDS <- c("a2lqRX2Mr0", "9Yqdwg85vJ")
 
     .obj <- asa_client$get_goalkeeper_goals_added(team_ids = IDS) %>%
-        tidyr::unnest(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
         dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(.data$team_id %in% IDS) %>%
+        dplyr::filter(team_id %in% IDS) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -380,12 +380,12 @@ test_that("Querying goalkeeper-level goals added (g+) values works properly", {
     NAMES <- "Red Bulls"
 
     .obj <- asa_client$get_goalkeeper_goals_added(team_names = NAMES) %>%
-        tidyr::unnest(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
         dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), .data$team_name)) %>%
+        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), team_name)) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -394,12 +394,12 @@ test_that("Querying goalkeeper-level goals added (g+) values works properly", {
     NAMES <- c("Chicago", "Seattle")
 
     .obj <- asa_client$get_goalkeeper_goals_added(team_names = NAMES) %>%
-        tidyr::unnest(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
         dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), .data$team_name)) %>%
+        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), team_name)) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -424,20 +424,20 @@ test_that("Querying goalkeeper-level goals added (g+) values works properly", {
     # Single action type -------------------------------------------------
     .exp <- "Shotstopping"
     .obj <- asa_client$get_goalkeeper_goals_added(action_type = .exp) %>%
-        tidyr::unnest(.data$data) %>%
-        dplyr::distinct(.data$action_type) %>%
-        dplyr::arrange(.data$action_type) %>%
-        dplyr::pull(.data$action_type)
+        tidyr::unnest(data) %>%
+        dplyr::distinct(action_type) %>%
+        dplyr::arrange(action_type) %>%
+        dplyr::pull(action_type)
 
     expect_equal(.obj, .exp)
 
     # Multiple action types ----------------------------------------------
     .exp <- c("Shotstopping", "Sweeping")
     .obj <- asa_client$get_goalkeeper_goals_added(action_type = .exp) %>%
-        tidyr::unnest(.data$data) %>%
-        dplyr::distinct(.data$action_type) %>%
-        dplyr::arrange(.data$action_type) %>%
-        dplyr::pull(.data$action_type)
+        tidyr::unnest(data) %>%
+        dplyr::distinct(action_type) %>%
+        dplyr::arrange(action_type) %>%
+        dplyr::pull(action_type)
 
     expect_equal(.obj, .exp)
 
@@ -471,13 +471,13 @@ test_that("Querying team-level goals added (g+) values works properly", {
     LEAGUES <- "mls"
 
     .exp <- asa_client$teams %>%
-        tidyr::unnest(.data$competitions) %>%
-        dplyr::filter(.data$competitions %in% LEAGUES) %>%
-        dplyr::distinct(.data$team_id) %>%
-        dplyr::pull(.data$team_id)
+        tidyr::unnest(competitions) %>%
+        dplyr::filter(competitions %in% LEAGUES) %>%
+        dplyr::distinct(team_id) %>%
+        dplyr::pull(team_id)
 
     .obj <- asa_client$get_team_goals_added(leagues = LEAGUES) %>%
-        dplyr::mutate(obj = .data$team_id %in% .exp) %>%
+        dplyr::mutate(obj = team_id %in% .exp) %>%
         dplyr::pull(obj) %>%
         mean(na.rm = TRUE)
 
@@ -487,13 +487,13 @@ test_that("Querying team-level goals added (g+) values works properly", {
     LEAGUES <- c("mls", "uslc")
 
     .exp <- asa_client$teams %>%
-        tidyr::unnest(.data$competitions) %>%
-        dplyr::filter(.data$competitions %in% LEAGUES) %>%
-        dplyr::distinct(.data$team_id) %>%
-        dplyr::pull(.data$team_id)
+        tidyr::unnest(competitions) %>%
+        dplyr::filter(competitions %in% LEAGUES) %>%
+        dplyr::distinct(team_id) %>%
+        dplyr::pull(team_id)
 
     .obj <- asa_client$get_team_goals_added(leagues = LEAGUES) %>%
-        dplyr::mutate(obj = .data$team_id %in% .exp) %>%
+        dplyr::mutate(obj = team_id %in% .exp) %>%
         dplyr::pull(obj) %>%
         mean(na.rm = TRUE)
 
@@ -506,12 +506,12 @@ test_that("Querying team-level goals added (g+) values works properly", {
     IDS <- "NWMWlBK5lz"
 
     .obj <- asa_client$get_team_goals_added(team_ids = IDS) %>%
-        tidyr::unnest(.data$team_id) %>%
-        dplyr::distinct(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
+        dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(.data$team_id %in% IDS) %>%
+        dplyr::filter(team_id %in% IDS) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -520,12 +520,12 @@ test_that("Querying team-level goals added (g+) values works properly", {
     IDS <- c("a2lqRX2Mr0", "9Yqdwg85vJ")
 
     .obj <- asa_client$get_team_goals_added(team_ids = IDS) %>%
-        tidyr::unnest(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
         dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(.data$team_id %in% IDS) %>%
+        dplyr::filter(team_id %in% IDS) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -534,12 +534,12 @@ test_that("Querying team-level goals added (g+) values works properly", {
     NAMES <- "Red Bulls"
 
     .obj <- asa_client$get_team_goals_added(team_names = NAMES) %>%
-        tidyr::unnest(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
         dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), .data$team_name)) %>%
+        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), team_name)) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -548,12 +548,12 @@ test_that("Querying team-level goals added (g+) values works properly", {
     NAMES <- c("Chicago", "Seattle")
 
     .obj <- asa_client$get_team_goals_added(team_names = NAMES) %>%
-        tidyr::unnest(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
         dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), .data$team_name)) %>%
+        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), team_name)) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -565,20 +565,20 @@ test_that("Querying team-level goals added (g+) values works properly", {
     # Single action type -------------------------------------------------
     .exp <- "Passing"
     .obj <- asa_client$get_team_goals_added(action_type = .exp) %>%
-        tidyr::unnest(.data$data) %>%
-        dplyr::distinct(.data$action_type) %>%
-        dplyr::arrange(.data$action_type) %>%
-        dplyr::pull(.data$action_type)
+        tidyr::unnest(data) %>%
+        dplyr::distinct(action_type) %>%
+        dplyr::arrange(action_type) %>%
+        dplyr::pull(action_type)
 
     expect_equal(.obj, .exp)
 
     # Multiple action types ----------------------------------------------
     .exp <- c("Passing", "Shooting")
     .obj <- asa_client$get_team_goals_added(action_type = .exp) %>%
-        tidyr::unnest(.data$data) %>%
-        dplyr::distinct(.data$action_type) %>%
-        dplyr::arrange(.data$action_type) %>%
-        dplyr::pull(.data$action_type)
+        tidyr::unnest(data) %>%
+        dplyr::distinct(action_type) %>%
+        dplyr::arrange(action_type) %>%
+        dplyr::pull(action_type)
 
     expect_equal(.obj, .exp)
 
