@@ -20,13 +20,13 @@ test_that("Querying player-level salary values works properly", {
     LEAGUES <- "mls"
 
     .exp <- asa_client$players %>%
-        tidyr::unnest(.data$competitions) %>%
-        dplyr::filter(.data$competitions %in% LEAGUES) %>%
-        dplyr::distinct(.data$player_id) %>%
-        dplyr::pull(.data$player_id)
+        tidyr::unnest(competitions) %>%
+        dplyr::filter(competitions %in% LEAGUES) %>%
+        dplyr::distinct(player_id) %>%
+        dplyr::pull(player_id)
 
     .obj <- asa_client$get_player_salaries(leagues = LEAGUES) %>%
-        dplyr::mutate(obj = .data$player_id %in% .exp) %>%
+        dplyr::mutate(obj = player_id %in% .exp) %>%
         dplyr::pull(obj) %>%
         mean(na.rm = TRUE)
 
@@ -39,11 +39,11 @@ test_that("Querying player-level salary values works properly", {
     IDS <- "vzqo8xZQap"
 
     .obj <- asa_client$get_player_salaries(player_ids = IDS) %>%
-        dplyr::distinct(.data$player_id) %>%
+        dplyr::distinct(player_id) %>%
         nrow()
 
     .exp <- asa_client$players %>%
-        dplyr::filter(.data$player_id %in% IDS) %>%
+        dplyr::filter(player_id %in% IDS) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -52,11 +52,11 @@ test_that("Querying player-level salary values works properly", {
     IDS <- c("vzqo8xZQap", "9vQ22BR7QK")
 
     .obj <- asa_client$get_player_salaries(player_ids = IDS) %>%
-        dplyr::distinct(.data$player_id) %>%
+        dplyr::distinct(player_id) %>%
         nrow()
 
     .exp <- asa_client$players %>%
-        dplyr::filter(.data$player_id %in% IDS) %>%
+        dplyr::filter(player_id %in% IDS) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -65,11 +65,11 @@ test_that("Querying player-level salary values works properly", {
     NAMES <- "Dax McCarty"
 
     .obj <- asa_client$get_player_salaries(player_names = NAMES) %>%
-        dplyr::distinct(.data$player_id) %>%
+        dplyr::distinct(player_id) %>%
         nrow()
 
     .exp <- asa_client$players %>%
-        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), .data$player_name)) %>%
+        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), player_name)) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -78,11 +78,11 @@ test_that("Querying player-level salary values works properly", {
     NAMES <- c("Dax McCarty", "Sean Davis")
 
     .obj <- asa_client$get_player_salaries(player_names = NAMES) %>%
-        dplyr::distinct(.data$player_id) %>%
+        dplyr::distinct(player_id) %>%
         nrow()
 
     .exp <- asa_client$players %>%
-        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), .data$player_name)) %>%
+        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), player_name)) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -94,12 +94,12 @@ test_that("Querying player-level salary values works properly", {
     IDS <- "NWMWlBK5lz"
 
     .obj <- asa_client$get_player_salaries(team_ids = IDS) %>%
-        tidyr::unnest(.data$team_id) %>%
-        dplyr::distinct(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
+        dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(.data$team_id %in% IDS) %>%
+        dplyr::filter(team_id %in% IDS) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -108,12 +108,12 @@ test_that("Querying player-level salary values works properly", {
     IDS <- c("a2lqRX2Mr0", "lgpMOvnQzy")
 
     .obj <- asa_client$get_player_salaries(team_ids = IDS) %>%
-        tidyr::unnest(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
         dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(.data$team_id %in% IDS) %>%
+        dplyr::filter(team_id %in% IDS) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -123,14 +123,14 @@ test_that("Querying player-level salary values works properly", {
     LEAGUES <- "mls"
 
     .obj <- asa_client$get_player_salaries(team_names = NAMES, leagues = LEAGUES) %>%
-        tidyr::unnest(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
         dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        tidyr::unnest(.data$competitions) %>%
-        dplyr::filter(.data$competitions %in% LEAGUES) %>%
-        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), .data$team_name)) %>%
+        tidyr::unnest(competitions) %>%
+        dplyr::filter(competitions %in% LEAGUES) %>%
+        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), team_name)) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -140,14 +140,14 @@ test_that("Querying player-level salary values works properly", {
     LEAGUES <- "mls"
 
     .obj <- asa_client$get_player_salaries(team_names = NAMES, leagues = LEAGUES) %>%
-        tidyr::unnest(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
         dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        tidyr::unnest(.data$competitions) %>%
-        dplyr::filter(.data$competitions %in% LEAGUES) %>%
-        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), .data$team_name)) %>%
+        tidyr::unnest(competitions) %>%
+        dplyr::filter(competitions %in% LEAGUES) %>%
+        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), team_name)) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -190,14 +190,14 @@ test_that("Querying team-level salary values works properly", {
     LEAGUES <- "mls"
 
     .exp <- asa_client$teams %>%
-        tidyr::unnest(.data$competitions) %>%
-        dplyr::filter(.data$competitions %in% LEAGUES) %>%
-        dplyr::distinct(.data$team_id) %>%
-        dplyr::pull(.data$team_id)
+        tidyr::unnest(competitions) %>%
+        dplyr::filter(competitions %in% LEAGUES) %>%
+        dplyr::distinct(team_id) %>%
+        dplyr::pull(team_id)
 
     .obj <- asa_client$get_team_salaries(leagues = LEAGUES) %>%
         dplyr::filter(!is.na(team_id)) %>%
-        dplyr::mutate(obj = .data$team_id %in% .exp) %>%
+        dplyr::mutate(obj = team_id %in% .exp) %>%
         dplyr::pull(obj) %>%
         mean(na.rm = TRUE)
 
@@ -210,12 +210,12 @@ test_that("Querying team-level salary values works properly", {
     IDS <- "NWMWlBK5lz"
 
     .obj <- asa_client$get_team_salaries(team_ids = IDS) %>%
-        tidyr::unnest(.data$team_id) %>%
-        dplyr::distinct(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
+        dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(.data$team_id %in% IDS) %>%
+        dplyr::filter(team_id %in% IDS) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -224,12 +224,12 @@ test_that("Querying team-level salary values works properly", {
     IDS <- c("a2lqRX2Mr0", "lgpMOvnQzy")
 
     .obj <- asa_client$get_team_salaries(team_ids = IDS) %>%
-        tidyr::unnest(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
         dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        dplyr::filter(.data$team_id %in% IDS) %>%
+        dplyr::filter(team_id %in% IDS) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -239,14 +239,14 @@ test_that("Querying team-level salary values works properly", {
     LEAGUES <- "mls"
 
     .obj <- asa_client$get_team_salaries(team_names = NAMES) %>%
-        tidyr::unnest(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
         dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        tidyr::unnest(.data$competitions) %>%
-        dplyr::filter(.data$competitions %in% LEAGUES) %>%
-        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), .data$team_name)) %>%
+        tidyr::unnest(competitions) %>%
+        dplyr::filter(competitions %in% LEAGUES) %>%
+        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), team_name)) %>%
         nrow()
 
     expect_equal(.obj, .exp)
@@ -256,14 +256,14 @@ test_that("Querying team-level salary values works properly", {
     LEAGUES <- "mls"
 
     .obj <- asa_client$get_team_salaries(team_names = NAMES) %>%
-        tidyr::unnest(.data$team_id) %>%
+        tidyr::unnest(team_id) %>%
         dplyr::distinct(team_id) %>%
         nrow()
 
     .exp <- asa_client$teams %>%
-        tidyr::unnest(.data$competitions) %>%
-        dplyr::filter(.data$competitions %in% LEAGUES) %>%
-        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), .data$team_name)) %>%
+        tidyr::unnest(competitions) %>%
+        dplyr::filter(competitions %in% LEAGUES) %>%
+        dplyr::filter(grepl(paste0(NAMES, collapse = "|"), team_name)) %>%
         nrow()
 
     expect_equal(.obj, .exp)
